@@ -1,17 +1,19 @@
 package action
 
 import (
-	"bytes"
 	"context"
 	"path/filepath"
 	"strings"
 	"testing"
 
+	"github.com/helmwave/helmwave/pkg/release"
+
 	"github.com/helmwave/helmwave/pkg/plan"
 	"github.com/helmwave/helmwave/pkg/repo"
 	"github.com/helmwave/helmwave/pkg/template"
 	"github.com/helmwave/helmwave/tests"
 	log "github.com/sirupsen/logrus"
+	logTest "github.com/sirupsen/logrus/hooks/test"
 	"github.com/stretchr/testify/suite"
 	"github.com/urfave/cli/v2"
 )
@@ -164,8 +166,8 @@ func (ts *BuildTestSuite) TestNonUniqueReleases() {
 	err = sb.tags.Set("nginx-b")
 	ts.Require().NoError(err)
 
-	ts.Require().ErrorIs(sfail.Run(context.Background()), plan.DuplicateReleasesError{})
-	ts.Require().ErrorIs(sfailByTag.Run(context.Background()), plan.DuplicateReleasesError{})
+	ts.Require().ErrorIs(sfail.Run(context.Background()), release.DuplicateError{})
+	ts.Require().ErrorIs(sfailByTag.Run(context.Background()), release.DuplicateError{})
 	ts.Require().NoError(sa.Run(context.Background()))
 	ts.Require().NoError(sb.Run(context.Background()))
 }
@@ -268,14 +270,39 @@ func (ts *BuildTestSuite) TestDiffLocal() {
 
 type NonParallelBuildTestSuite struct {
 	suite.Suite
+
+	defaultHooks log.LevelHooks
+	logHook      *logTest.Hook
 }
 
-//nolintlint:paralleltest // can't parallel because of setenv and uses helm repository.yaml flock
+//nolint:paralleltest // can't parallel because of setenv and uses helm repository.yaml flock
 func TestNonParallelNonParallelBuildTestSuite(t *testing.T) {
 	// t.Parallel()
 	suite.Run(t, new(NonParallelBuildTestSuite))
 }
 
+func (ts *NonParallelBuildTestSuite) SetupSuite() {
+	ts.defaultHooks = log.StandardLogger().Hooks
+	ts.logHook = logTest.NewLocal(log.StandardLogger())
+}
+
+func (ts *NonParallelBuildTestSuite) TearDownTestSuite() {
+	ts.logHook.Reset()
+}
+
+func (ts *NonParallelBuildTestSuite) TearDownSuite() {
+	log.StandardLogger().ReplaceHooks(ts.defaultHooks)
+}
+
+func (ts *NonParallelBuildTestSuite) getLoggerMessages() []string {
+	res := make([]string, len(ts.logHook.Entries))
+	for i, entry := range ts.logHook.AllEntries() {
+		res[i] = entry.Message
+	}
+
+	return res
+}
+
 func (ts *NonParallelBuildTestSuite) TestAutoYml() {
 	tmpDir := ts.T().TempDir()
 	y := &Yml{
@@ -341,17 +368,12 @@ func (ts *NonParallelBuildTestSuite) TestLifecycle() {
 		yml:     y,
 	}
 
-	var buf bytes.Buffer
-	oldOut := log.StandardLogger().Out
-	log.StandardLogger().SetOutput(&buf)
-	defer log.StandardLogger().SetOutput(oldOut)
-
 	ts.Require().NoError(s.Run(context.Background()))
 	ts.Require().DirExists(filepath.Join(s.plandir, plan.Manifest))
 
-	output := buf.String()
-	ts.Require().Contains(output, "running pre_build script for nginx")
-	ts.Require().Contains(output, "run global pre_build script")
-	ts.Require().Contains(output, "running post_build script for nginx")
-	ts.Require().Contains(output, "run global post_build script")
+	logMessages := ts.getLoggerMessages()
+	ts.Require().Contains(logMessages, "running pre_build script for nginx")
+	ts.Require().Contains(logMessages, "run global pre_build script")
+	ts.Require().Contains(logMessages, "running post_build script for nginx")
+	ts.Require().Contains(logMessages, "run global post_build script")
 }
