@@ -1,8 +1,6 @@
 package plan
 
 import (
-	"errors"
-
 	regi "github.com/helmwave/helmwave/pkg/registry"
 	"github.com/helmwave/helmwave/pkg/release"
 	log "github.com/sirupsen/logrus"
@@ -32,9 +30,9 @@ func buildRegistries(m map[string][]release.Config, in []regi.Config) (out []reg
 			out = append(out, in[index])
 			l.Info("🗄 registry has been added to the plan")
 		} else {
-			l.WithField("releases", rm).Warn("🗄 some releases depend on repository that is not defined")
+			l.WithField("releases", rm).Warn("🗄 some releases depend on a registry that is not defined")
 
-			return nil, errors.New("🗄 not found " + reg)
+			return nil, regi.NewNotFoundError(reg)
 		}
 	}
 
