@@ -1,7 +1,6 @@
 package plan
 
 import (
-	"errors"
 	"os"
 
 	"github.com/helmwave/helmwave/pkg/release"
@@ -32,35 +31,13 @@ func buildRepositories(m map[string][]release.Config, in []repo.Config) (out []r
 		} else {
 			l.WithField("releases", rm).Warn("🗄 some releases depend on repository that is not defined")
 
-			return nil, errors.New("🗄 not found " + rep)
+			return nil, repo.NewNotFoundError(rep)
 		}
 	}
 
 	return out, nil
 }
 
-// func buildRepoMapDeps(releases []*release.Config) (map[string][]*release.Config, error) {
-//	m := make(map[string][]*release.Config)
-//	for _, rel := range releases {
-//		reps, err := rel.RepoDeps()
-//		if err != nil {
-//			return nil, err
-//		}
-//
-//		log.WithFields(log.Fields{
-//			"release":      rel.Uniq(),
-//			"repositories": reps,
-//		}).Trace("RepoDeps names")
-//
-//		for _, rep := range reps {
-//			m[rep] = append(m[rep], rel)
-//		}
-//	}
-//
-//	return m, nil
-//
-// }
-
 func buildRepoMapTop(releases []release.Config) map[string][]release.Config {
 	m := make(map[string][]release.Config)
 	for _, rel := range releases {
@@ -73,22 +50,7 @@ func buildRepoMapTop(releases []release.Config) map[string][]release.Config {
 	return m
 }
 
-// // allRepos for releases.
-// func allRepos(releases []*release.Config) ([]string, error) {
-//	var all []string
-//	for _, rel := range releases {
-//		r, err := rel.RepoDeps()
-//		if err != nil {
-//			return nil, err
-//		}
-//
-//		all = append(all, r...)
-//	}
-//
-//	return all, nil
-// }
-
-// repoIsLocal return true if repo is dir.
+// repoIsLocal returns true if repo is a dir.
 func repoIsLocal(repoString string) bool {
 	if repoString == "" {
 		return true
