@@ -1,10 +1,13 @@
 package plan_test
 
 import (
+	"errors"
 	"os"
 	"path/filepath"
 	"testing"
 
+	"github.com/helmwave/helmwave/pkg/repo"
+
 	"github.com/helmwave/helmwave/pkg/plan"
 	"github.com/helmwave/helmwave/pkg/release"
 	"github.com/helmwave/helmwave/pkg/template"
@@ -16,6 +19,47 @@ type ValidateTestSuite struct {
 	suite.Suite
 }
 
+func TestValidateTestSuite(t *testing.T) {
+	t.Parallel()
+	suite.Run(t, new(ValidateTestSuite))
+}
+
+func (s *ValidateTestSuite) TestInvalidRelease() {
+	tmpDir := s.T().TempDir()
+	p := plan.New(filepath.Join(tmpDir, plan.Dir))
+	body := p.NewBody()
+
+	err := errors.New("test error")
+
+	mockedRelease := &plan.MockReleaseConfig{}
+	mockedRelease.On("Validate").Return(err)
+
+	p.SetReleases(mockedRelease)
+
+	s.Require().ErrorIs(err, body.ValidateReleases())
+	s.Require().Error(err, body.Validate())
+
+	mockedRelease.AssertExpectations(s.T())
+}
+
+func (s *ValidateTestSuite) TestInvalidRepository() {
+	tmpDir := s.T().TempDir()
+	p := plan.New(filepath.Join(tmpDir, plan.Dir))
+	body := p.NewBody()
+
+	err := errors.New("test error")
+
+	mockedRepo := &plan.MockRepositoryConfig{}
+	mockedRepo.On("Validate").Return(err)
+
+	p.SetRepositories(mockedRepo)
+
+	s.Require().ErrorIs(err, body.ValidateRepositories())
+	s.Require().Error(err, body.Validate())
+
+	mockedRepo.AssertExpectations(s.T())
+}
+
 func (s *ValidateTestSuite) TestValidateValues() {
 	tmpDir := s.T().TempDir()
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
@@ -69,141 +113,23 @@ func (s *ValidateTestSuite) TestValidateValuesNoReleases() {
 	s.Require().NoError(p.ValidateValuesImport())
 }
 
-func (s *ValidateTestSuite) TestValidateRepositoryName() {
-	tmpDir := s.T().TempDir()
-	p := plan.New(filepath.Join(tmpDir, plan.Dir))
-	body := p.NewBody()
-
-	mockedRepo := &plan.MockRepoConfig{}
-	mockedRepo.On("Name").Return("")
-
-	p.SetRepositories(mockedRepo)
-
-	s.Require().Error(body.ValidateRepositories())
-	s.Require().Error(body.Validate())
-
-	mockedRepo.AssertExpectations(s.T())
-}
-
-func (s *ValidateTestSuite) TestValidateRepositoryURLEmpty() {
-	tmpDir := s.T().TempDir()
-	p := plan.New(filepath.Join(tmpDir, plan.Dir))
-	body := p.NewBody()
-
-	mockedRepo := &plan.MockRepoConfig{}
-	mockedRepo.On("Name").Return("blabla")
-	mockedRepo.On("URL").Return("")
-
-	p.SetRepositories(mockedRepo)
-
-	s.Require().Error(body.ValidateRepositories())
-	s.Require().Error(body.Validate())
-
-	mockedRepo.AssertExpectations(s.T())
-}
-
-func (s *ValidateTestSuite) TestValidateRepositoryURL() {
-	tmpDir := s.T().TempDir()
-	p := plan.New(filepath.Join(tmpDir, plan.Dir))
-	body := p.NewBody()
-
-	mockedRepo := &plan.MockRepoConfig{}
-	mockedRepo.On("Name").Return("blabla")
-	mockedRepo.On("URL").Return("\\asdasd://null")
-
-	p.SetRepositories(mockedRepo)
-
-	s.Require().Error(body.ValidateRepositories())
-	s.Require().Error(body.Validate())
-
-	mockedRepo.AssertExpectations(s.T())
-}
-
 func (s *ValidateTestSuite) TestValidateRepositoryDuplicate() {
 	tmpDir := s.T().TempDir()
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
 	body := p.NewBody()
 
-	mockedRepo := &plan.MockRepoConfig{}
+	mockedRepo := &plan.MockRepositoryConfig{}
 	mockedRepo.On("Name").Return("blabla")
-	mockedRepo.On("URL").Return("http://localhost")
+	mockedRepo.On("Validate").Return(nil)
 
 	p.SetRepositories(mockedRepo, mockedRepo)
 
-	s.Require().Error(body.ValidateRepositories())
-	s.Require().Error(body.Validate())
+	s.Require().ErrorIs(repo.DuplicateError{}, body.ValidateRepositories())
+	s.Require().ErrorIs(repo.DuplicateError{}, body.Validate())
 
 	mockedRepo.AssertExpectations(s.T())
 }
 
-func (s *ValidateTestSuite) TestValidateRepository() {
-	tmpDir := s.T().TempDir()
-	p := plan.New(filepath.Join(tmpDir, plan.Dir))
-	body := p.NewBody()
-
-	mockedRepo := &plan.MockRepoConfig{}
-	mockedRepo.On("Name").Return("blabla")
-	mockedRepo.On("URL").Return("http://localhost")
-
-	p.SetRepositories(mockedRepo)
-
-	s.Require().NoError(body.ValidateRepositories())
-	s.Require().NoError(body.Validate())
-
-	mockedRepo.AssertExpectations(s.T())
-}
-
-func (s *ValidateTestSuite) TestValidateReleaseName() {
-	tmpDir := s.T().TempDir()
-	p := plan.New(filepath.Join(tmpDir, plan.Dir))
-	body := p.NewBody()
-
-	mockedRelease := &plan.MockReleaseConfig{}
-	mockedRelease.On("Name").Return("")
-
-	p.SetReleases(mockedRelease)
-
-	s.Require().Error(body.ValidateReleases())
-	s.Require().Error(body.Validate())
-
-	mockedRelease.AssertExpectations(s.T())
-}
-
-func (s *ValidateTestSuite) TestValidateReleaseNamespace() {
-	tmpDir := s.T().TempDir()
-	p := plan.New(filepath.Join(tmpDir, plan.Dir))
-	body := p.NewBody()
-
-	mockedRelease := &plan.MockReleaseConfig{}
-	mockedRelease.On("Name").Return("blabla")
-	mockedRelease.On("Namespace").Return("///")
-
-	p.SetReleases(mockedRelease)
-
-	s.Require().Error(body.ValidateReleases())
-	s.Require().Error(body.Validate())
-
-	mockedRelease.AssertExpectations(s.T())
-}
-
-func (s *ValidateTestSuite) TestValidateReleaseUniq() {
-	tmpDir := s.T().TempDir()
-	p := plan.New(filepath.Join(tmpDir, plan.Dir))
-	body := p.NewBody()
-
-	mockedRelease := &plan.MockReleaseConfig{}
-	mockedRelease.On("Name").Return("blabla")
-	mockedRelease.On("Namespace").Return("defaultblabla")
-	mockedRelease.On("Uniq").Return()
-
-	p.SetReleases(mockedRelease)
-
-	s.Require().NoError(body.ValidateReleases())
-	s.Require().NoError(body.Validate())
-
-	mockedRelease.AssertExpectations(s.T())
-}
-
 func (s *ValidateTestSuite) TestValidateReleaseDuplicate() {
 	tmpDir := s.T().TempDir()
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
@@ -213,11 +139,12 @@ func (s *ValidateTestSuite) TestValidateReleaseDuplicate() {
 	mockedRelease.On("Name").Return("blabla")
 	mockedRelease.On("Namespace").Return("defaultblabla")
 	mockedRelease.On("Uniq").Return()
+	mockedRelease.On("Validate").Return(nil)
 
 	p.SetReleases(mockedRelease, mockedRelease)
 
-	s.Require().Error(body.ValidateReleases())
-	s.Require().Error(body.Validate())
+	s.Require().ErrorIs(release.DuplicateError{}, body.ValidateReleases())
+	s.Require().ErrorIs(release.DuplicateError{}, body.Validate())
 
 	mockedRelease.AssertExpectations(s.T())
 }
@@ -227,11 +154,5 @@ func (s *ValidateTestSuite) TestValidateEmpty() {
 	p := plan.New(filepath.Join(tmpDir, plan.Dir))
 	body := p.NewBody()
 
-	err := body.Validate()
-	s.Require().Error(err)
-}
-
-func TestValidateTestSuite(t *testing.T) {
-	t.Parallel()
-	suite.Run(t, new(ValidateTestSuite))
+	s.Require().NoError(body.Validate())
 }
