@@ -1,7 +1,6 @@
 package release
 
 import (
-	"errors"
 	"sync"
 	"time"
 
@@ -9,11 +8,9 @@ import (
 	"github.com/helmwave/helmwave/pkg/hooks"
 	"github.com/helmwave/helmwave/pkg/release/uniqname"
 	log "github.com/sirupsen/logrus"
-	"helm.sh/helm/v3/pkg/action"
 	"helm.sh/helm/v3/pkg/chartutil"
 	helm "helm.sh/helm/v3/pkg/cli"
 	"helm.sh/helm/v3/pkg/postrender"
-	"helm.sh/helm/v3/pkg/storage/driver"
 )
 
 type config struct {
@@ -33,9 +30,11 @@ type config struct {
 	OfflineKubeVersionF string `yaml:"offline_kube_version,omitempty" json:"offline_kube_version,omitempty" jsonschema:"description=Kubernetes version for offline mode"`
 
 	DependsOnF    []*DependsOnReference `yaml:"depends_on,omitempty" json:"depends_on,omitempty" jsonschema:"title=Needs,description=List of dependencies that are required to succeed before this release"`
+	MonitorsF     []MonitorReference    `yaml:"monitors,omitempty" json:"monitors,omitempty" jsonschema:"title=Monitors to execute after upgrade"`
 	ValuesF       []ValuesReference     `yaml:"values,omitempty" json:"values,omitempty" jsonschema:"title=Values of the release,oneof_type=string;object"`
 	TagsF         []string              `yaml:"tags,omitempty" json:"tags,omitempty" jsonschema:"description=Tags allows you choose releases for build"`
 	PostRendererF []string              `yaml:"post_renderer,omitempty" json:"post_renderer,omitempty" jsonschema:"description=List of post_renders to manipulate with manifests"`
+	ShowNotes     bool                  `yaml:"show_notes,omitempty" json:"show_notes,omitempty" jsonschema:"description=Output rendered chart notes after upgrade/install"`
 
 	Timeout time.Duration `yaml:"timeout,omitempty" json:"timeout,omitempty" jsonschema:"oneof_type=string;int,default=5m"`
 
@@ -67,100 +66,6 @@ func (rel *config) DryRun(b bool) {
 	rel.dryRun = b
 }
 
-func (rel *config) newInstall() *action.Install {
-	client := action.NewInstall(rel.Cfg())
-
-	// client.IncludeCRDs = true
-
-	// Only Up
-	client.CreateNamespace = rel.CreateNamespace
-	client.ReleaseName = rel.Name()
-
-	// Common Part
-	client.DryRun = rel.dryRun
-	client.Namespace = rel.Namespace()
-	client.EnableDNS = rel.EnableDNS
-
-	rel.Chart().CopyOptions(&client.ChartPathOptions)
-
-	client.DisableHooks = rel.DisableHooks
-	client.SkipCRDs = rel.SkipCRDs
-	client.Timeout = rel.Timeout
-	client.Wait = rel.Wait
-	client.WaitForJobs = rel.WaitForJobs
-	client.Atomic = rel.Atomic
-	client.DisableOpenAPIValidation = rel.DisableOpenAPIValidation
-	client.SubNotes = rel.SubNotes
-	client.Description = rel.Description()
-
-	pr, err := rel.PostRenderer()
-	if err != nil {
-		rel.Logger().WithError(err).Warn("failed to create post-renderer")
-	} else {
-		client.PostRenderer = pr
-	}
-
-	if client.DryRun {
-		client.Replace = true
-	}
-
-	if client.DryRun && nil != rel.OfflineKubeVersion() {
-		client.ClientOnly = true
-		client.KubeVersion = rel.OfflineKubeVersion()
-	}
-
-	return client
-}
-
-func (rel *config) newUpgrade() *action.Upgrade {
-	client := action.NewUpgrade(rel.Cfg())
-
-	// Only Upgrade
-	client.CleanupOnFail = rel.CleanupOnFail
-	client.MaxHistory = rel.MaxHistory
-	client.Recreate = rel.Recreate
-	client.ReuseValues = rel.ReuseValues
-	client.ResetValues = rel.ResetValues
-
-	// Common Part
-	client.DryRun = rel.dryRun
-	client.Namespace = rel.Namespace()
-	client.EnableDNS = rel.EnableDNS
-
-	rel.Chart().CopyOptions(&client.ChartPathOptions)
-
-	client.Force = rel.Force
-	client.DisableHooks = rel.DisableHooks
-	client.SkipCRDs = rel.SkipCRDs
-	client.Timeout = rel.Timeout
-	client.Wait = rel.Wait
-	client.WaitForJobs = rel.WaitForJobs
-	client.Atomic = rel.Atomic
-	client.DisableOpenAPIValidation = rel.DisableOpenAPIValidation
-	client.SubNotes = rel.SubNotes
-	client.Description = rel.Description()
-
-	pr, err := rel.PostRenderer()
-	if err != nil {
-		rel.Logger().WithError(err).Warn("failed to create post_renderer")
-	} else {
-		client.PostRenderer = pr
-	}
-
-	return client
-}
-
-var (
-	// ErrNotFound is an error for not found release.
-	ErrNotFound = driver.ErrReleaseNotFound
-
-	// ErrFoundMultiple is an error for multiple releases found by name.
-	ErrFoundMultiple = errors.New("found multiple releases o_0")
-
-	// ErrDepFailed is an error thrown when dependency release fails.
-	ErrDepFailed = errors.New("dependency failed")
-)
-
 // Uniq like redis@my-namespace.
 func (rel *config) Uniq() uniqname.UniqName {
 	if rel.uniqName == "" {
@@ -336,3 +241,10 @@ func (rel *config) OfflineKubeVersion() *chartutil.KubeVersion {
 
 	return nil
 }
+
+func (rel *config) Monitors() []MonitorReference {
+	rel.lock.RLock()
+	defer rel.lock.RUnlock()
+
+	return rel.MonitorsF
+}
